@@ -3,7 +3,7 @@ from typing import Iterable, Mapping
 from chaoslib import Configuration, Secrets
 from logzero import logger
 
-from chaosazure import init_client
+from chaosazure import init_compute_management_client
 from chaosazure.common import cleanse
 from chaosazure.common.compute import command
 from chaosazure.vmss.fetcher import fetch_vmss, fetch_instances
@@ -48,8 +48,8 @@ def delete_vmss(filter: str = None,
         for instance in instances:
             logger.debug(
                 "Deleting instance: {}".format(instance['name']))
-            client = init_client(secrets, configuration)
-            client.virtual_machine_scale_set_vms.delete(
+            client = init_compute_management_client(secrets, configuration)
+            client.virtual_machine_scale_set_vms.begin_delete(
                 scale_set['resourceGroup'],
                 scale_set['name'],
                 instance['instance_id'])
@@ -90,8 +90,8 @@ def restart_vmss(filter: str = None,
         for instance in instances:
             logger.debug(
                 "Restarting instance: {}".format(instance['name']))
-            client = init_client(secrets, configuration)
-            client.virtual_machine_scale_set_vms.restart(
+            client = init_compute_management_client(secrets, configuration)
+            client.virtual_machine_scale_set_vms.begin_restart(
                 scale_set['resourceGroup'],
                 scale_set['name'],
                 instance['instance_id'])
@@ -154,8 +154,8 @@ def stop_vmss(filter: str = None,
         for instance in instances:
             logger.debug(
                 "Stopping instance: {}".format(instance['name']))
-            client = init_client(secrets, configuration)
-            client.virtual_machine_scale_set_vms.power_off(
+            client = init_compute_management_client(secrets, configuration)
+            client.virtual_machine_scale_set_vms.begin_power_off(
                 scale_set['resourceGroup'],
                 scale_set['name'],
                 instance['instance_id'])
@@ -196,8 +196,8 @@ def deallocate_vmss(filter: str = None,
         for instance in instances:
             logger.debug(
                 "Deallocating instance: {}".format(instance['name']))
-            client = init_client(secrets, configuration)
-            client.virtual_machine_scale_set_vms.deallocate(
+            client = init_compute_management_client(secrets, configuration)
+            client.virtual_machine_scale_set_vms.begin_deallocate(
                 scale_set['resourceGroup'],
                 scale_set['name'],
                 instance['instance_id'])
@@ -216,7 +216,7 @@ def stress_vmss_instance_cpu(
         instance_criteria: Iterable[Mapping[str, any]] = None,
         configuration: Configuration = None,
         secrets: Secrets = None):
-    logger.warn(
+    logger.warning(
         "Deprecated usage of activity 'stress_vmss_instance_cpu'."
         " Please use activity 'stress_cpu' in favor since this"
         " activity will be removed in a future release.")
